==> deepin-system-monitor_1.0.0-1.tar.xz: deepin-system-monitor-1.4.8/translations/deepin-system-monitor_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Procesnaam</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Opdrachtregel</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Starttijd</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>Processor</translation>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation>Schijfuitlezing</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Schijfwegschrijving</translation>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Geheugen</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Wisselgeheugen</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Niet ingeschakeld</translation>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Totaal</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>Processor</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation>Schijf</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Schijfuitlezing</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Schijfwegschrijving</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Applicatie geforceerd beëindigen</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Donker thema</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Applicatie beëindigen</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Het beëindigen van deze applicatie kan gegevensverlies veroorzaken.
Weet je zeker dat je door wilt gaan?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation>Compacte modus</translation>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Geheugen</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Wisselgeheugen</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Niet ingeschakeld</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Totaal</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Geen antwoord</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pauzeren</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Proces beëindigen</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Het beëindigen van dit proces kan gegevensverlies veroorzaken.
Weet je zeker dat je door wilt gaan?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Proces pauzeren</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Proces hervatten</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Proceslocatie tonen</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>Er worden %2 applicaties en %3 processen uitgevoerd</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>Processor</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Geheugen</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Schijfwegschrijving</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Schijfuitlezing</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Deepin Systeemmonitor is een intuïtieve, krachtige systeemmonitor. Het kan processen, CPU, geheugen, netwerk, schijf en andere statussen monitoren.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin Systeemmonitor</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin Systeemmonitor</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Bureaubladomgeving - Procesinitiatie-dienst</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Bureaubladomgeving - Bureaublad</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Bureaubladomgeving - Polkit-proxy</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Bureaubladomgeving - Startmenu</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Bureaubladomgeving - Dock</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Bureaubladomgeving - Schermweergave</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Bureaubladomgeving - Achtergronddienst</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Bureaubladomgeving - Sessie-achtergronddienst</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Bureaubladomgeving - Sessie-initialisatieproces</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Deepin Bestandsbeheer-achtergronddienst</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Bureaubladomgeving - Schermvergrendelingsdienst</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Deepin Vensterbeheer</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Deepin Vensterbeheer-schakelaar</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Deepin-melding</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Deepin Cloud Afdrukken-dienst</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Deepin menu-dienst</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Deepin Winkel-achtergronddienst</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Vensterovereenkomst-achtergronddienst</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Vensterovereenkomst-achtergronddienst - DBus-dienst</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>SSH-dienst</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Gebruikersmodus - virtueel bestandssysteem-achtergronddienst</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Fuse-server van gebruikersmodus - virtueel bestandssysteem-achtergronddienst</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Hulpproces van Deepin Winkel</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Netwerkbeheer</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>PolicyKit DBus-dienst</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Bestandsdeling-achtergronddienst</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>X-dienst</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Fcitx-invoermethode</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Fcitx-invoermethode - DBus-achtergronddienst</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Sogou-invoermethode - DBus-achtergronddienst</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>ShadowSocks lokale client</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Geluidsdienst</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Afdrukdienst</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>LightDM-beeldschermbeheer</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Systeemdienstbeheer</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Systeemdienstbeheer - Apparaatbeheer-achtergronddienst</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Schijfdienst</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Accountdienst</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>DBus-dienst</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Muisgebeurtenis-dienst</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>DConf-dienst</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Gnome sleutelbos-dienst</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Bluetooth-dienst</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Energiedienst</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Modemapparaatbeheer</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Systeem-afdruklade-dienst</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Chrome-webbrowser sandbox</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Synaptics touchpad apparaatdenst</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Wisselgeheugen</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Niet ingeschakeld</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation>Sogou-invoermethode</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Klik op de te beëindigen applicatie</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Applicaties</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mijn processen</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Alle processen</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Systeemvak</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
</context>
</TS>

==> deepin-system-monitor_1.4.3.orig.tar.xz: deepin-system-monitor-1.4.3/translations/deepin-system-monitor_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>AttributesDialog</name>
    <message>
        <source>Process name</source>
        <translation>Proces naam</translation>
    </message>
    <message>
        <source>Command line</source>
        <translation>Opdrachtregel</translation>
    </message>
    <message>
        <source>Start time</source>
        <translation>Starttijd</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactDiskMonitor</name>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactMemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Swap</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CompactNetworkMonitor</name>
    <message>
        <source>Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Total</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
</context>
<context>
    <name>DiskMonitor</name>
    <message>
        <source>Disk</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk read</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disk write</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Force to end application</source>
        <translation>Toepassing forceren te beëindigen</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Donker thema</translation>
    </message>
    <message>
        <source>End application</source>
        <translation>Toepassing beëindigen</translation>
    </message>
    <message>
        <source>Ending this application may cause data loss.
Are you sure to continue?</source>
        <translation>Het beëindigen van deze applicatie kan gegevensverlies veroorzaken
Weet u zeker dat u verder wilt gaan?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Compact mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MemoryMonitor</name>
    <message>
        <source>Memory</source>
        <translation>Geheugen</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Wisselen</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Niet ingeschakeld</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Total</source>
        <translation>Totaal</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
</context>
<context>
    <name>ProcessItem</name>
    <message>
        <source>No response</source>
        <translation>Geen antwoord</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Opschorten</translation>
    </message>
</context>
<context>
    <name>ProcessManager</name>
    <message>
        <source>End process</source>
        <translation>Proces beëindigen</translation>
    </message>
    <message>
        <source>Ending this process may cause data loss.
Are you sure to continue?</source>
        <translation>Het beëindigen van dit proces kan gegevensverlies veroorzaken
Weet u zeker dat u verder wilt gaan?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Suspend process</source>
        <translation>Proces opschorten</translation>
    </message>
    <message>
        <source>Resume process</source>
        <translation>Proces hervatten</translation>
    </message>
    <message>
        <source>View process location</source>
        <translation>Proces locatie bekijken</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>%2 applications and %3 processes are running</source>
        <translation>%2 toepassingen en %3 processen worden uitgevoerd</translation>
    </message>
</context>
<context>
    <name>ProcessView</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Geheugen</translation>
    </message>
    <message>
        <source>Disk write</source>
        <translation>Schrijven naar schijf</translation>
    </message>
    <message>
        <source>Disk read</source>
        <translation>Lezen van schijf</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Downloaden</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Uploaden</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Deepin System Monitor is an intuitive and powerful system monitor. It can monitor the process CPU, memory, network, disk and other status.</source>
        <translation>Deepin Systeemmonitor is een intuïtief en krachtig systeemmonitor. Het kan processen, CPU, geheugen, netwerk, schijf en andere status monitoren.</translation>
    </message>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin Systeemmonitor</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Deepin System Monitor</source>
        <translation>Deepin Systeemmonitor</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Process initiation service</source>
        <translation>Deepin Desktopomgeving - Proces initiatie service</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Desktop</source>
        <translation>Deepin Desktopomgeving - Bureaublad</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Polkit proxy</source>
        <translation>Deepin Desktopomgeving - Polkit proxy</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Launcher</source>
        <translation>Deepin Desktopomgeving - Startmenu</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Dock</source>
        <translation>Deepin Desktop Environment - Dock</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Screen display</source>
        <translation>Deepin Desktopomgeving - Schermweergave</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Daemon</source>
        <translation>Deepin Desktopomgeving - Daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session daemon</source>
        <translation>Deepin Desktopomgeving - Sessie daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Session initialization process</source>
        <translation>Deepin Desktopomgeving - Sessie initialisatie proces</translation>
    </message>
    <message>
        <source>Deepin File Manager daemon</source>
        <translation>Deepin Bestandsbeheer daemon</translation>
    </message>
    <message>
        <source>Deepin Desktop Environment - Lock screen service</source>
        <translation>Deepin Desktopomgeving - Schermvergrendeling service</translation>
    </message>
    <message>
        <source>Deepin Window Manager </source>
        <translation>Deepin Vensterbeheer</translation>
    </message>
    <message>
        <source>Deepin Window Manager switcher</source>
        <translation>Deepin Vensterbeheer wisselen</translation>
    </message>
    <message>
        <source>Deepin notification</source>
        <translation>Deepin notificatie</translation>
    </message>
    <message>
        <source>Deepin Cloud Print agent</source>
        <translation>Deepin Cloud Afdrukken agent</translation>
    </message>
    <message>
        <source>Deepin menu service</source>
        <translation>Deepin menu service</translation>
    </message>
    <message>
        <source>Deepin Store daemon</source>
        <translation>Deepin Winkel daemon</translation>
    </message>
    <message>
        <source>Window match daemon</source>
        <translation>Venster overeenkomst daemon</translation>
    </message>
    <message>
        <source>Window match daemon DBus service</source>
        <translation>Venster overeenkomst daemon DBus service</translation>
    </message>
    <message>
        <source>SSH agent</source>
        <translation>SSH agent</translation>
    </message>
    <message>
        <source>User mode virtual file system daemon</source>
        <translation>Gebruikersmodus virtueel bestandssysteem daemon</translation>
    </message>
    <message>
        <source>Fuse server of user mode virtual file system daemon</source>
        <translation>Samenvoeg server van gebruikersmodus virtueel bestandssysteem daemon</translation>
    </message>
    <message>
        <source>Helper process of Deepin Store client</source>
        <translation>Hulpproces van Deepin Winkel client</translation>
    </message>
    <message>
        <source>Network manager</source>
        <translation>Netwerkbeheer</translation>
    </message>
    <message>
        <source>PolicyKit DBus service</source>
        <translation>PolicyKit DBus service</translation>
    </message>
    <message>
        <source>File sharing service daemon</source>
        <translation>Bestandsdeling service daemon</translation>
    </message>
    <message>
        <source>X service</source>
        <translation>X service</translation>
    </message>
    <message>
        <source>Fcitx input method</source>
        <translation>Fcitx invoer methode</translation>
    </message>
    <message>
        <source>Fcitx input method DBus daemon</source>
        <translation>Fcitx invoer methode DBus daemon</translation>
    </message>
    <message>
        <source>Sogou input method daemon</source>
        <translation>Sogou invoer methode DBus daemon</translation>
    </message>
    <message>
        <source>ShadowSocks local client</source>
        <translation>ShadowSocks lokale client</translation>
    </message>
    <message>
        <source>Sound service</source>
        <translation>Geluidservice</translation>
    </message>
    <message>
        <source>Print daemon</source>
        <translation>Afdruk daemon</translation>
    </message>
    <message>
        <source>Light display manager</source>
        <translation>Lichte beeldschermbeheer</translation>
    </message>
    <message>
        <source>System service manager</source>
        <translation>Systeem servicebeheer</translation>
    </message>
    <message>
        <source>System service manager - Device management daemon</source>
        <translation>Systeem servicebeheer - Apparaatbeheer daemon</translation>
    </message>
    <message>
        <source>Disk daemon</source>
        <translation>Schijf daemon</translation>
    </message>
    <message>
        <source>Account daemon</source>
        <translation>Account daemon</translation>
    </message>
    <message>
        <source>DBus daemon</source>
        <translation>DBus daemon</translation>
    </message>
    <message>
        <source>Mouse event daemon</source>
        <translation>Muis gebeurtenis daemon</translation>
    </message>
    <message>
        <source>DConf service</source>
        <translation>DConf service</translation>
    </message>
    <message>
        <source>Gnome keyring daemon</source>
        <translation>Gnome sleutelring daemon</translation>
    </message>
    <message>
        <source>Bluetooth daemon</source>
        <translation>Bluetooth daemon</translation>
    </message>
    <message>
        <source>Power daemon</source>
        <translation>Vermogen daemon</translation>
    </message>
    <message>
        <source>Modem device manager</source>
        <translation>Modem apparaatbeheer</translation>
    </message>
    <message>
        <source>System print tray service</source>
        <translation>Systeem afdruklade service</translation>
    </message>
    <message>
        <source>Chrome browser sandbox</source>
        <translation>Chrome browser zandbak</translation>
    </message>
    <message>
        <source>Synaptics touchpad device daemon</source>
        <translation>Synaptics touchpad apparaat daemon</translation>
    </message>
    <message>
        <source>Swap</source>
        <translation>Wisselen</translation>
    </message>
    <message>
        <source>Not enabled</source>
        <translation>Niet ingeschakeld</translation>
    </message>
    <message>
        <source>Sogou input method</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click the application you want to end</source>
        <translation>Klik op de toepassing die u wilt beëindigen</translation>
    </message>
</context>
<context>
    <name>StatusMonitor</name>
    <message>
        <source>Applications</source>
        <translation>Toepassingen</translation>
    </message>
    <message>
        <source>My processes</source>
        <translation>Mijn processen</translation>
    </message>
    <message>
        <source>All processes</source>
        <translation>Alle processen</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
</context>
</TS>
